<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'travel_master_pro_service_section', array(
	'title'             => esc_html__( 'Services','travel-master-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_service_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

// Servuce count number control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'travel_master_pro_sanitize_number_range',
	'validate_callback' => 'travel_master_pro_validate_service_count',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-master-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_service_section',
	'active_callback'   => 'travel_master_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-master-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-master-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-master-pro' ),
	),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Icon_Picker( $wp_customize, 'travel_master_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_service_section',
		'active_callback'	=> 'travel_master_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_service_section',
		'choices'			=> travel_master_pro_page_choices(),
		'active_callback'	=> 'travel_master_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_service_section',
		'choices'			=> travel_master_pro_post_choices(),
		'active_callback'	=> 'travel_master_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'travel_master_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_master_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'travel_master_pro_service_section',
			'active_callback' => 'travel_master_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-master-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_service_section_content_category_enable'
) ) );
